==> RDRToolbox_1.0.0.zip: RDRToolbox/doc/vignette.R <==
###################################################
### chunk number 1: 
###################################################
#line 38 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpORYs3C/R.INSTALL6f5c486b/RDRToolbox/inst/doc/vignette.Rnw"
options(width=60)
options(continue=" ")
set.seed(1234)


###################################################
### chunk number 2: preliminaries
###################################################
#line 55 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpORYs3C/R.INSTALL6f5c486b/RDRToolbox/inst/doc/vignette.Rnw"
library(RDRToolbox)


###################################################
### chunk number 3:  eval=FALSE
###################################################
## #line 69 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpORYs3C/R.INSTALL6f5c486b/RDRToolbox/inst/doc/vignette.Rnw"
## swissData=SwissRoll(N = 1000, Plot=TRUE)


###################################################
### chunk number 4: 
###################################################
#line 89 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpORYs3C/R.INSTALL6f5c486b/RDRToolbox/inst/doc/vignette.Rnw"
sim = generateData(samples=20, genes=1000, diffgenes=100, diffsamples=10)
simData = sim[[1]]
simLabels = sim[[2]]


###################################################
### chunk number 5: 
###################################################
#line 95 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpORYs3C/R.INSTALL6f5c486b/RDRToolbox/inst/doc/vignette.Rnw"
sim = generateData(samples=20, genes=1000, diffgenes=100, cov1=0.2, cov2=0, blocksize=10)
simData = sim[[1]]
simLabels = sim[[2]]


###################################################
### chunk number 6: 
###################################################
#line 111 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpORYs3C/R.INSTALL6f5c486b/RDRToolbox/inst/doc/vignette.Rnw"
simData_dim3_lle = LLE(data=simData, dim=3, k=10)
head(simData_dim3_lle)
simData_dim2_lle = LLE(data=simData, dim=2, k=5)
head(simData_dim2_lle)


###################################################
### chunk number 7: 
###################################################
#line 123 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpORYs3C/R.INSTALL6f5c486b/RDRToolbox/inst/doc/vignette.Rnw"
simData_dim2_IM = Isomap(data=simData, dims=2, k=10)
head(simData_dim2_IM$dim2)


###################################################
### chunk number 8: 
###################################################
#line 129 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpORYs3C/R.INSTALL6f5c486b/RDRToolbox/inst/doc/vignette.Rnw"
simData_dim1to10_IM = Isomap(data=simData, dims=1:10, k=10, plotResiduals=TRUE) 


###################################################
### chunk number 9:  eval=FALSE
###################################################
## #line 134 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpORYs3C/R.INSTALL6f5c486b/RDRToolbox/inst/doc/vignette.Rnw"
## Isomap(data=simData, dims=2, mod=TRUE, k=10)


###################################################
### chunk number 10: 
###################################################
#line 146 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpORYs3C/R.INSTALL6f5c486b/RDRToolbox/inst/doc/vignette.Rnw"
plotDR(data=simData_dim2_lle, labels=simLabels)


###################################################
### chunk number 11: 
###################################################
#line 152 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpORYs3C/R.INSTALL6f5c486b/RDRToolbox/inst/doc/vignette.Rnw"
samples = c(rep("class 1", 10), rep("class 2", 10)) #letters[1:20]
labels = c("first component", "second component")
plotDR(data=simData_dim2_lle, labels=simLabels, axesLabels=labels, text=samples)


###################################################
### chunk number 12:  eval=FALSE
###################################################
## #line 159 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpORYs3C/R.INSTALL6f5c486b/RDRToolbox/inst/doc/vignette.Rnw"
## plotDR(data=simData_dim3_lle, labels=simLabels)


###################################################
### chunk number 13: 
###################################################
#line 175 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpORYs3C/R.INSTALL6f5c486b/RDRToolbox/inst/doc/vignette.Rnw"
d = generateData(samples=20, genes=50, diffgenes=10, blocksize=5)
DBIndex(data=d[[1]], labels=d[[2]])


###################################################
### chunk number 14: 
###################################################
#line 180 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpORYs3C/R.INSTALL6f5c486b/RDRToolbox/inst/doc/vignette.Rnw"
DBIndex(data=simData_dim2_lle, labels=simLabels)


###################################################
### chunk number 15: 
###################################################
#line 190 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpORYs3C/R.INSTALL6f5c486b/RDRToolbox/inst/doc/vignette.Rnw"
library(golubEsets)
data(Golub_Merge)


###################################################
### chunk number 16: 
###################################################
#line 196 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpORYs3C/R.INSTALL6f5c486b/RDRToolbox/inst/doc/vignette.Rnw"
golubExprs = t(exprs(Golub_Merge))
labels = pData(Golub_Merge)$ALL.AML
dim(golubExprs)
show(labels)


###################################################
### chunk number 17: 
###################################################
#line 204 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpORYs3C/R.INSTALL6f5c486b/RDRToolbox/inst/doc/vignette.Rnw"
Isomap(data=golubExprs, dims=1:10, plotResiduals=TRUE, k=5)


###################################################
### chunk number 18: 
###################################################
#line 210 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpORYs3C/R.INSTALL6f5c486b/RDRToolbox/inst/doc/vignette.Rnw"
golubIsomap = Isomap(data=golubExprs, dims=2, k=5)
golubLLE = LLE(data=golubExprs, dim=2, k=5)


###################################################
### chunk number 19: 
###################################################
#line 215 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpORYs3C/R.INSTALL6f5c486b/RDRToolbox/inst/doc/vignette.Rnw"
DBIndex(data=golubIsomap$dim2, labels=labels)
DBIndex(data=golubLLE, labels=labels)


###################################################
### chunk number 20: plotGolubIsomap
###################################################
#line 220 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpORYs3C/R.INSTALL6f5c486b/RDRToolbox/inst/doc/vignette.Rnw"
plotDR(data=golubIsomap$dim2, labels=labels, axesLabels=c("", ""), legend=TRUE)
title(main="Isomap")


###################################################
### chunk number 21: plotGolubLLE
###################################################
#line 224 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpORYs3C/R.INSTALL6f5c486b/RDRToolbox/inst/doc/vignette.Rnw"
plotDR(data=golubLLE, labels=labels, axesLabels=c("", ""), legend=TRUE)
title(main="LLE")

==> RDRToolbox_1.2.0.zip: RDRToolbox/doc/vignette.R <==
###################################################
### chunk number 1: 
###################################################
#line 38 "vignette.Rnw"
options(width=60)
options(continue=" ")
set.seed(1234)


###################################################
### chunk number 2: preliminaries
###################################################
#line 55 "vignette.Rnw"
library(RDRToolbox)


###################################################
### chunk number 3:  eval=FALSE
###################################################
## #line 69 "vignette.Rnw"
## swissData=SwissRoll(N = 1000, Plot=TRUE)


###################################################
### chunk number 4: 
###################################################
#line 89 "vignette.Rnw"
sim = generateData(samples=20, genes=1000, diffgenes=100, diffsamples=10)
simData = sim[[1]]
simLabels = sim[[2]]


###################################################
### chunk number 5: 
###################################################
#line 95 "vignette.Rnw"
sim = generateData(samples=20, genes=1000, diffgenes=100, cov1=0.2, cov2=0, blocksize=10)
simData = sim[[1]]
simLabels = sim[[2]]


###################################################
### chunk number 6: 
###################################################
#line 111 "vignette.Rnw"
simData_dim3_lle = LLE(data=simData, dim=3, k=10)
head(simData_dim3_lle)
simData_dim2_lle = LLE(data=simData, dim=2, k=5)
head(simData_dim2_lle)


###################################################
### chunk number 7: 
###################################################
#line 123 "vignette.Rnw"
simData_dim2_IM = Isomap(data=simData, dims=2, k=10)
head(simData_dim2_IM$dim2)


###################################################
### chunk number 8: 
###################################################
#line 129 "vignette.Rnw"
simData_dim1to10_IM = Isomap(data=simData, dims=1:10, k=10, plotResiduals=TRUE) 


###################################################
### chunk number 9:  eval=FALSE
###################################################
## #line 134 "vignette.Rnw"
## Isomap(data=simData, dims=2, mod=TRUE, k=10)


###################################################
### chunk number 10: 
###################################################
#line 146 "vignette.Rnw"
plotDR(data=simData_dim2_lle, labels=simLabels)


###################################################
### chunk number 11: 
###################################################
#line 152 "vignette.Rnw"
samples = c(rep("class 1", 10), rep("class 2", 10)) #letters[1:20]
labels = c("first component", "second component")
plotDR(data=simData_dim2_lle, labels=simLabels, axesLabels=labels, text=samples)


###################################################
### chunk number 12:  eval=FALSE
###################################################
## #line 159 "vignette.Rnw"
## plotDR(data=simData_dim3_lle, labels=simLabels)


###################################################
### chunk number 13: 
###################################################
#line 175 "vignette.Rnw"
d = generateData(samples=20, genes=50, diffgenes=10, blocksize=5)
DBIndex(data=d[[1]], labels=d[[2]])


###################################################
### chunk number 14: 
###################################################
#line 180 "vignette.Rnw"
DBIndex(data=simData_dim2_lle, labels=simLabels)


###################################################
### chunk number 15: 
###################################################
#line 190 "vignette.Rnw"
library(golubEsets)
data(Golub_Merge)


###################################################
### chunk number 16: 
###################################################
#line 196 "vignette.Rnw"
golubExprs = t(exprs(Golub_Merge))
labels = pData(Golub_Merge)$ALL.AML
dim(golubExprs)
show(labels)


###################################################
### chunk number 17: 
###################################################
#line 204 "vignette.Rnw"
Isomap(data=golubExprs, dims=1:10, plotResiduals=TRUE, k=5)


###################################################
### chunk number 18: 
###################################################
#line 210 "vignette.Rnw"
golubIsomap = Isomap(data=golubExprs, dims=2, k=5)
golubLLE = LLE(data=golubExprs, dim=2, k=5)


###################################################
### chunk number 19: 
###################################################
#line 215 "vignette.Rnw"
DBIndex(data=golubIsomap$dim2, labels=labels)
DBIndex(data=golubLLE, labels=labels)


###################################################
### chunk number 20: plotGolubIsomap
###################################################
#line 220 "vignette.Rnw"
plotDR(data=golubIsomap$dim2, labels=labels, axesLabels=c("", ""), legend=TRUE)
title(main="Isomap")


###################################################
### chunk number 21: plotGolubLLE
###################################################
#line 224 "vignette.Rnw"
plotDR(data=golubLLE, labels=labels, axesLabels=c("", ""), legend=TRUE)
title(main="LLE")
